data.items: Multiple-Choice, Dichotomous, and Polytomous Item Data

data.itemsR Documentation

Multiple-Choice, Dichotomous, and Polytomous Item Data

Description

An example data set with ten multiple-choice test items, scored dichotomous test items, and six polytomous item with four response options, i.e., 0 = "I strongly disagree", 1 = "I disagree", 2 = "I agree", and 3 = "I strongly agree". Note that the inverted items pitem2 and pitem3 need to be reverse coded before conducting the analysis. The example data is based on the dichotomous and timms2011_usa data objects provided in the package itemanalysis by Cengiz Zopluoglu.

Format

A data frame with 1,000 rows and 27 columns:

id

Identifier, i.e., consecutive numbers from 1 to 1,000

group2

arbitrary grouping variable with two groups

group4

arbitrary grouping variable with fout groups

mitem1

MC test items 1 with four response options A, B, and C, and D

mitem2

MC test items 2 with four response options A, B, C, and D

mitem3

MC test items 3 with three response options A, B, and C

mitem4

MC test items 4 with three response options A, B, and C

mitem5

MC test items 5 with four response options A, B, C, and D

mitem6

MC test items 6 with three response options A, B, and C

mitem7

MC test items 7 with four response options A, B, C, and D

mitem8

MC test items 8 with four response options A, B, C, and D

mitem9

MC test items 9 with three response options A, B, and C

mitem10

MC test items 10 with three response options A, B, and C

ditem1

Scored MC test item 1

ditem2

Scored MC test item 2

ditem3

Scored MC test item 3

ditem4

Scored MC test item 4

ditem5

Scored MC test item 5

ditem6

Scored MC test item 6

ditem7

Scored MC test item 7

ditem8

Scored MC test item 8

ditem9

Scored MC test item 9

ditem10

Scored MC test item 10

pitem1

I enjoy learning mathematics.

pitem2

I wish have not to study Math. (inverted item)

pitem3

Mathematics is boring.(inverted item)

pitem4

I learn interesting things in mathematics class.

pitem5

I like mathematics.

pitem6

I think it's important to do well in mathematics.

pitem2r

Reverse coded item 'pitem2'

pitem3r

Reverse coded item 'pitem3'

<https://cran.r-project.org/web/packages/itemanalysis/>


misty documentation built on Aug. 2, 2026, 9:06 a.m.

Related to data.items in misty...