| item.omega | R Documentation |
This function computes point estimate and confidence interval for the coefficient omega (McDonald, 1999), hierarchical coefficient omega (Kelley & Pornprasertmanit, 2016), and categorical coefficient omega (Green & Yang, 2009) along with standardized factor loadings and omega if item deleted. By default, the function computes coefficient omega based on maximum likelihood parameter (ML) estimates using full information maximum likelihood (FIML) method in the presence of missing data.
item.omega(data, ..., rescov = NULL, type = c("omega", "hierarch", "categ"),
exclude = NULL, std = FALSE,
estimator = c("ML", "GLS", "WLS", "DWLS", "ULS", "PML"),
missing = c("listwise", "pairwise", "fiml"),
print = c("all", "omega", "item"), digits = 2, r.digits = 3,
conf.level = 0.95, as.na = NULL, write = NULL, append = TRUE,
check = TRUE, output = TRUE)
data |
a data frame. Note that at least three items are needed for computing coefficient omega |
... |
an expression indicating the variable names in |
rescov |
a character vector or a list of character vectors for
specifying residual covariances when computing coefficient
omega, e.g. |
type |
a character string indicating the type of omega to be computed,
i.e., |
exclude |
a character vector indicating items to be excluded from the analysis. |
std |
logical: if |
estimator |
a character string indicating the estimator to be used
(see 'Details' in the |
missing |
a character string indicating how to deal with missing data.
(see 'Details' in the |
print |
a character vector indicating which results to show, i.e.
|
digits |
an integer value indicating the number of decimal places to be used for displaying mean, standard deviation, minimum, and maximum. |
r.digits |
an integer value indicating the number of decimal places to be used for displaying alpha and standardized factor loadings. |
conf.level |
a numeric value between 0 and 1 indicating the confidence level of the interval. |
as.na |
a numeric vector indicating user-defined missing values,
i.e. these values are converted to |
write |
a character string naming a file for writing the output into
either a text file with file extension |
append |
logical: if |
check |
logical: if |
output |
logical: if |
This function computes the coefficient omega
by conducting a confirmatory factor analysis based on the congeneric measurement
model (Graham, 2006) using the cfa() function in the lavaan package
by Yves Rosseel (2019).
The confidence interval for the (ordinal)
coefficient alpha is computed using the procedure by Feldt et al. (1987).
Note that there are at least 10 other procedures for computing the confidence
interval (see Kelley and Pornprasertmanit, 2016), which are implemented in the
ci.reliability() function in the MBESSS package by Ken Kelley (2019).
Returns an object of class misty.object, which is a list with following
entries:
call |
function call |
type |
type of analysis |
data |
data frame used for the current analysis |
args |
specification of function arguments |
model.fit |
fitted lavaan object ( |
result |
list with result tables, i.e., |
Computation of the hierarchical and categorical omega is based on the
ci.reliability() function in the MBESS package by Ken Kelley
(2019).
Takuya Yanagida takuya.yanagida@univie.ac.at
Feldt, L. S., Woodruff, D. J., & Salih, F. A. (1987). Statistical inference for coefficient alpha. Applied Psychological Measurement, 11 93-103. https://doi.org/10.1177/014662168701100107
Graham, J. M. (2006). Congeneric and (essentially) tau-equivalent estimates of score reliability: What they are and how to use them. Educational and Psychological Measurement, 66(6), 930–944. https://doi.org/10.1177/0013164406288165
Kelley, K., & Pornprasertmanit, S. (2016). Confidence intervals for population reliability coefficients: Evaluation of methods, recommendations, and software for composite measures. Psychological Methods, 21, 69-92. https://doi.org/10.1037/a0040086.
Ken Kelley (2019). MBESS: The MBESS R Package. R package version 4.6.0. https://CRAN.R-project.org/package=MBESS
McDonald, R. P. (1999). Test theory: A unified treatment. Lawrence Erlbaum Associates Publishers.
item.omega, item.cfa, item.invar,
item.reverse, item.scores, write.result
## Not run:
# Load data set "HolzingerSwineford1939" in the lavaan package
data("HolzingerSwineford1939", package = "lavaan")
#————————————————————————————————————————————————————————————————————————————
# Continuous Data
# Example 1a: Coefficient omega
item.omega(HolzingerSwineford1939, x1::x9)
# Example 1b: Coefficient omega and item statistics after excluding 'x3'
item.omega(HolzingerSwineford1939, x1::x9, exclude = "x3", print = "all")
# Example 2: Hierarchical Omega
item.omega(HolzingerSwineford1939, x1::x9, type = "hierarch")
# Example 3a: Residual covariance between 'x1' and 'x2'
item.omega(HolzingerSwineford1939, x1::x9, rescov = c("x1", "x2"))
# Example 3b: Residual covariances between 'x1' and 'x2', and 'x2' and 'x3'
item.omega(HolzingerSwineford1939, x1::x9, rescov = list(c("x1", "x2"), c("x2", "x3")))
# Example 4: Summary of the CFA model used to compute coefficient omega
lavaan::summary(item.omega(HolzingerSwineford1939, x1::x9, output = FALSE)$model.fit,
standardized = TRUE)
#————————————————————————————————————————————————————————————————————————————
# Polytomous Data
# Example 5: Ordinal coefficient omega and item statistics
item.omega(data.items, pitem1, pitem2r, pitem3r, pitem4::pitem6, type = "categ",
print = "all")
#————————————————————————————————————————————————————————————————————————————
# Write Results
# Example 6a: Write Results into a text file
item.omega(HolzingerSwineford1939, x1::x9, print = "all", write = "Omega.txt")
# Example 6b: Write Results into an Excel file
item.omega(HolzingerSwineford1939, x1::x9, print = "all", write = "Omega.xlsx")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.