View source: R/print.misty.object.R
| print.misty.object | R Documentation |
This function prints an misty.object object.
## S3 method for class 'misty.object'
print(x, sort.var = x$args$sort.var,
digits = x$args$digits, p.digits = x$args$p.digits,
icc.digits = x$args$icc.digits, r.digits = x$args$r.digits,
ess.digits = x$args$ess.digits, mcse.digits = x$args$mcse.digits,
check = TRUE, ...)
x |
|
sort.var |
logical: if |
digits |
an integer value indicating the number of decimal places to be used for displaying results. |
p.digits |
an integer indicating the number of decimal places to be used for displaying p-values. |
icc.digits |
an integer indicating the number of decimal places to be used
for displaying intraclass correlation coefficients
( |
r.digits |
an integer value indicating the number of decimal places to be used for displaying R-hat values, item-total correlation standardized factor loadings, coefficient alpha, and coefficient omega. |
ess.digits |
an integer value indicating the number of decimal places to be used for displaying effective sample sizes. |
mcse.digits |
an integer value indicating the number of decimal places to be used for displaying Monte Carlo standard errors. |
check |
logical: if |
... |
further arguments passed to or from other methods. |
Takuya Yanagida takuya.yanagida@univie.ac.at
## Not run:
#————————————————————————————————————————————————————————————————————————————
# Example 1: item.cfa() function
# Load data set "HolzingerSwineford1939" in the lavaan package
data("HolzingerSwineford1939", package = "lavaan")
result <- item.cfa(HolzingerSwineford1939[, c("x1", "x2", "x3")], output = FALSE)
print(result)
#————————————————————————————————————————————————————————————————————————————
# Example 2: multilevel.descript() function
# Load data set "Demo.twolevel" in the lavaan package
data("Demo.twolevel", package = "lavaan")
result <- multilevel.descript(y1:y3, data = Demo.twolevel, cluster = "cluster",
output = FALSE)
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.