write.result: Write Results of a misty Object into an Excel file

View source: R/write.result.R

write.resultR Documentation

Write Results of a misty Object into an Excel file

Description

This function writes the results of a misty.object) into an Excel file.

Usage

write.result(x, file = "Results.xlsx", digits = x$args$digits,
             p.digits = x$args$p.digits, icc.digits = x$args$icc.digits,
             r.digits = x$args$r.digits, ess.digits = x$args$ess.digits,
             mcse.digits = x$args$mcse.digits, check = TRUE)

Arguments

x

misty object (misty.object) resulting from a misty function supported by the write.result function (see 'Details').

file

a character string naming a file with or without file extension '.xlsx', e.g., "Results.xlsx" or "Results".

digits

an integer value indicating the number of decimal places digits to be used for displaying results.

p.digits

an integer indicating the number of decimal places to be used for displaying p-values.

icc.digits

an integer indicating the number of decimal places to be used for displaying intraclass correlation coefficients.

r.digits

an integer value indicating the number of decimal places to be used for displaying R-hat values, item-total correlation standardized factor loadings, coefficient alpha, and coefficient omega.

ess.digits

an integer value indicating the number of decimal places to be used for displaying effective sample sizes.

mcse.digits

an integer value indicating the number of decimal places to be used for displaying Monte Carlo standard errors.

check

logical: if TRUE (default), argument specification is checked.

Details

Currently the function supports result objects from the following functions:

blimp.bayes, boot.bs,ci.cor, ci.mean, ci.median, ci.prop, ci.var, ci.sd, coeff.robust, coeff.std, cor.matrix, crosstab, descript, difftest.chibarsq, dominance.manual, dominance, effsize, freq, item.alpha, item.cfa, item.dfi, item.distract, item.invar, item.omega, item.stats, mplus.bayes, multilevel.cfa, multilevel.cor, multilevel.descript, multilevel.fit, multilevel.invar, item.noninvar, multilevel.omega, na.auxiliary, na.coverage, na.descript, na.pattern, mplus.lca.summa, summa and uniq

Author(s)

Takuya Yanagida takuya.yanagida@univie.ac.at

Examples

## Not run: 
#————————————————————————————————————————————————————————————————————————————
# Example 1: item.cfa() function

# Load data set "HolzingerSwineford1939" in the lavaan package
data("HolzingerSwineford1939", package = "lavaan")

result <- item.cfa(HolzingerSwineford1939[, c("x1", "x2", "x3")], output = FALSE)
write.result(result, "CFA.xlsx")

#————————————————————————————————————————————————————————————————————————————
# Example 2: multilevel.descript() function

# Load data set "Demo.twolevel" in the lavaan package
data("Demo.twolevel", package = "lavaan")

result <- multilevel.descript(y1:y3, data = Demo.twolevel, cluster = "cluster",
                              output = FALSE)
write.result(result, "Multilevel_Descript.xlsx")

## End(Not run)

misty documentation built on Aug. 2, 2026, 9:06 a.m.

Related to write.result in misty...