| aov.b | R Documentation |
This function performs an one-way between-subject analysis of variance (ANOVA) including Tukey HSD post hoc tests for multiple comparison and provides descriptive statistics, effect size measures, and a plot showing bars representing means for each group and error bars for difference-adjusted confidence intervals.
aov.b(formula, data, hypo = FALSE, descript = FALSE, effsize = FALSE,
weighted = TRUE, correct = FALSE, posthoc = FALSE, conf.level = 0.95,
digits = 2, p.digits = 3, as.na = NULL, plot = FALSE, bar = TRUE,
point = FALSE, ci = TRUE, jitter = FALSE, adjust = TRUE,
filename = NULL, width = NA, height = NA, dpi = 600,
write = NULL, append = TRUE, check = TRUE, output = TRUE)
formula |
a formula of the form |
data |
a matrix or data frame containing the variables in the
formula |
hypo |
logical: if |
descript |
logical: if |
effsize |
logical: if |
weighted |
logical: if |
correct |
logical: if |
posthoc |
logical: if |
conf.level |
a numeric value between 0 and 1 indicating the confidence level of the interval. |
digits |
an integer value indicating the number of decimal places to be used for displaying descriptive statistics and confidence interval. |
p.digits |
an integer value indicating the number of decimal places to be used for displaying the p-value. |
as.na |
a numeric vector indicating user-defined missing values,
i.e. these values are converted to |
plot |
logical: if |
bar |
logical: if |
point |
logical: if |
ci |
logical: if |
jitter |
logical: if |
adjust |
logical: if |
filename |
a character string indicating the |
width |
a numeric value indicating the |
height |
a numeric value indicating the |
dpi |
a numeric value indicating the |
write |
a character string naming a text file with file extension
|
append |
logical: if |
check |
logical: if |
output |
logical: if |
Cumming and Finch (2005) pointed out that
when 95% confidence intervals (CI) for two separately plotted means overlap,
it is still possible that the CI for the difference would not include zero.
Baguley (2012) proposed to adjust the width of the CIs by the factor of
\sqrt{2} to reflect the correct width of the CI for a mean difference:
\hat{\mu}_{j} \pm t_{n - 1, 1 - \alpha/2} \frac{\sqrt{2}}{2} \hat{\sigma}_{{\hat{\mu}}_j}
These difference-adjusted CIs around the individual means can be interpreted
as if it were a CI for their difference. Note that the width of these intervals
is sensitive to differences in the variance and sample size of each sample,
i.e., unequal population variances and unequal n alter the interpretation
of difference-adjusted CIs.
Returns an object of class misty.object, which is a list with following
entries:
call |
function call |
type |
type of analysis |
data |
data frame with variables used in the current analysis |
formula |
formula of the current analysis |
args |
specification of function arguments |
plot |
ggplot2 object for plotting the results |
result |
result tables |
Takuya Yanagida takuya.yanagida@univie.ac.at
Baguley, T. S. (2012a). Serious stats: A guide to advanced statistics for the behavioral sciences. Palgrave Macmillan.
Cumming, G., and Finch, S. (2005) Inference by eye: Confidence intervals, and how to read pictures of data. American Psychologist, 60, 170–80.
Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). Statistics in psychology - Using R and SPSS. John Wiley & Sons.
aov.w, test.t, test.z,
test.levene, aov.b, cohens.d,
ci.mean.diff, ci.mean
#————————————————————————————————————————————————————————————————————————————
# Between-Subject Analysis of Variance
# Example 1a: Between-Subject ANOVA
aov.b(hp ~ gear, data = mtcars)
# Example 1b: Between-Subject ANOVA
# Print descriptive statistics and Tukey HSD post hoc test
aov.b(hp ~ gear, data = mtcars, descript = TRUE, posthoc = TRUE)
# Example 1c: Between-Subject ANOVA, print eta-squared and omega-squared
aov.b(hp ~ gear, data = mtcars, effsize = TRUE)
#————————————————————————————————————————————————————————————————————————————
# Plot
# Example 2a: Plot results, default setting
aov.b(hp ~ gear, data = mtcars, plot = TRUE)
# Example 2b: Plot results
# No bars, draw points representing means and jittered data points
aov.b(hp ~ gear, data = mtcars, plot = TRUE, bar = FALSE, point = TRUE, jitter = TRUE)
# Example 2c: Plot results using the plot() function, use additional arguments
# see Details in the help page of the function plot.misty.object
object <- aov.b(hp ~ gear, data = mtcars)
plot(object, jitter = TRUE, jitter.alpha = 0.4, title = "Between-Subject ANOVA")
#————————————————————————————————————————————————————————————————————————————
# Create Plot Manually
# Load ggplot2 package
library(ggplot2)
# Create misty object
object <- aov.b(hp ~ gear, data = mtcars)
# Example 3: Plot
ggplot(object$result$descript, aes(group, y)) +
geom_bar(aes(group, m), stat = "summary", fun = "mean") +
geom_jitter(data = object$data, aes(group, y), alpha = 0.1, width = 0.05,
height = 0, size = 1.25) +
geom_point(aes(group, m), stat = "identity", size = 3) +
geom_errorbar(aes(group, m, ymin = low, ymax = upp), width = 0.1) +
theme_bw()
#————————————————————————————————————————————————————————————————————————————
# Write Results and Save Plot
## Not run:
# Example 4a: Write results into a text file
aov.b(hp ~ gear, data = mtcars, write = "ANOVA.txt")
# Example 4b: Write results into an Excel file
aov.b(hp ~ gear, data = mtcars, write = "ANOVA.xlsx")
# Example 4c: Save plot as PNG fine
aov.b(hp ~ gear, data = mtcars, plot = TRUE, filename = "ANOVA.png",
width = 6, height = 5)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.