| data.items | R Documentation |
An example data set with ten multiple-choice test items, scored dichotomous
test items, and six polytomous item with four response options, i.e., 0 = "I
strongly disagree", 1 = "I disagree", 2 = "I agree", and 3 = "I strongly agree".
Note that the inverted items pitem2 and pitem3 need to be reverse
coded before conducting the analysis. The example data is based on the dichotomous
and timms2011_usa data objects provided in the package itemanalysis
by Cengiz Zopluoglu.
A data frame with 1,000 rows and 27 columns:
Identifier, i.e., consecutive numbers from 1 to 1,000
arbitrary grouping variable with two groups
arbitrary grouping variable with fout groups
MC test items 1 with four response options A, B, and C, and D
MC test items 2 with four response options A, B, C, and D
MC test items 3 with three response options A, B, and C
MC test items 4 with three response options A, B, and C
MC test items 5 with four response options A, B, C, and D
MC test items 6 with three response options A, B, and C
MC test items 7 with four response options A, B, C, and D
MC test items 8 with four response options A, B, C, and D
MC test items 9 with three response options A, B, and C
MC test items 10 with three response options A, B, and C
Scored MC test item 1
Scored MC test item 2
Scored MC test item 3
Scored MC test item 4
Scored MC test item 5
Scored MC test item 6
Scored MC test item 7
Scored MC test item 8
Scored MC test item 9
Scored MC test item 10
I enjoy learning mathematics.
I wish have not to study Math. (inverted item)
Mathematics is boring.(inverted item)
I learn interesting things in mathematics class.
I like mathematics.
I think it's important to do well in mathematics.
Reverse coded item 'pitem2'
Reverse coded item 'pitem3'
<https://cran.r-project.org/web/packages/itemanalysis/>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.