Learn R Programming

misty (version 0.3.2)

print.misty.object: Print misty.object object

Description

This function prints the misty.object object

Usage

# S3 method for misty.object
print(x, print = x$args$print, tri = x$args$tri,
      freq = x$args$freq, split = x$args$split, table = x$args$table,
      digits = x$args$digits, p.digits = x$args$p.digits,
      icc.digits = x$args$icc.digits, sort.var = x$args$sort.var,
      order = x$args$order, check = TRUE, ...)

Arguments

x

misty.object object.

print

a character string or character vector indicating which results to to be printed on the console.

tri

a character string or character vector indicating which triangular of the matrix to show on the console, i.e., both for upper and lower triangular, lower for the lower triangular, and upper for the upper triangular.

freq

logical: if TRUE, absolute frequencies will be included in the cross tabulation (freq() function).

split

logical: if TRUE, cross table is split in absolute frequencies and percentage(s) (crosstab() function).

table

logical: if TRUE, a frequency table with number of observed values ("nObs"), percent of observed values ("pObs"), number of missing values ("nNA"), and percent of missing values ("pNA") is printed for each variable on the console (na.descript() function).

digits

an integer value indicating the number of decimal places digits to be used for displaying results.

p.digits

an integer indicating the number of decimal places to be used for displaying p-values.

icc.digits

an integer indicating the number of decimal places to be used for displaying intraclass correlation coefficients (multilevel.descript() function).

sort.var

logical: if TRUE, output is sorted by variables.

order

logical: if TRUE, variables are ordered from left to right in increasing order of missing values (na.descript() function).

check

logical: if TRUE, argument specification is checked.

...

further arguments passed to or from other methods.

See Also

alpha.coef, ci.mean.diff, ci.mean, ci.median, ci.prop.diff, ci.prop, ci.sd, ci.var, cohens.d, collin.diag, cont.coef, cor.matrix, cramers.v, crosstab, descript, eta.sq, freq, levenes.test, multilevel.descript, na.auxiliary, na.coverage, na.descript, na.pattern, omega.coef, phi.coef, poly.cor, size.cor, size.mean, size.prop, z.test,