This function prints the misty.object object
# S3 method for misty.object
print(x, print = x$args$print, tri = x$args$tri,
freq = x$args$freq, split = x$args$split, table = x$args$table,
digits = x$args$digits, p.digits = x$args$p.digits,
icc.digits = x$args$icc.digits, sort.var = x$args$sort.var,
order = x$args$order, check = TRUE, ...)misty.object object.
a character string or character vector indicating which results to to be printed on the console.
a character string or character vector indicating which triangular of the matrix
to show on the console, i.e., both for upper and lower triangular,
lower for the lower triangular, and upper for the upper
triangular.
logical: if TRUE, absolute frequencies will be included in the cross
tabulation (freq() function).
logical: if TRUE, cross table is split in absolute frequencies and percentage(s)
(crosstab() function).
logical: if TRUE, a frequency table with number of observed values ("nObs"),
percent of observed values ("pObs"), number of missing values ("nNA"), and
percent of missing values ("pNA") is printed for each variable on the console
(na.descript() function).
an integer value indicating the number of decimal places digits to be used for displaying results.
an integer indicating the number of decimal places to be used for displaying p-values.
an integer indicating the number of decimal places to be used for displaying
intraclass correlation coefficients (multilevel.descript() function).
logical: if TRUE, output is sorted by variables.
logical: if TRUE, variables are ordered from left to right in increasing order
of missing values (na.descript() function).
logical: if TRUE, argument specification is checked.
further arguments passed to or from other methods.
alpha.coef, ci.mean.diff, ci.mean, ci.median,
ci.prop.diff, ci.prop, ci.sd, ci.var,
cohens.d, collin.diag, cont.coef, cor.matrix,
cramers.v, crosstab, descript, eta.sq,
freq, levenes.test, multilevel.descript,
na.auxiliary, na.coverage, na.descript,
na.pattern, omega.coef, phi.coef, poly.cor,
size.cor, size.mean, size.prop, z.test,