| test.t | R Documentation |
This function performs one-sample, two-sample, and paired-sample t-tests and provides descriptive statistics, effect size measure, and a plot showing bar plots with error bars for (difference-adjusted) confidence intervals.
test.t(x, ...)
## Default S3 method:
test.t(x, y = NULL, mu = 0, paired = FALSE,
alternative = c("two.sided", "less", "greater"), hypo = FALSE,
descript = TRUE, effsize = FALSE, weighted = TRUE, cor = TRUE,
ref = NULL, correct = FALSE, conf.level = 0.95, digits = 2, p.digits = 3,
as.na = NULL, plot = FALSE, bar = TRUE, point = FALSE, ci = TRUE,
line = TRUE, jitter = FALSE, adjust = TRUE, filename = NULL,
width = NA, height = NA, dpi = 600, write = NULL, append = TRUE,
check = TRUE, output = TRUE, ...)
## S3 method for class 'formula'
test.t(formula, data, alternative = c("two.sided", "less", "greater"),
hypo = FALSE, descript = TRUE, effsize = FALSE, weighted = TRUE,
cor = TRUE, ref = NULL, correct = FALSE, conf.level = 0.95, digits = 2,
p.digits = 3, as.na = NULL, plot = FALSE, bar = TRUE, point = FALSE,
ci = TRUE, line = TRUE, jitter = FALSE, adjust = TRUE, filename = NULL,
width = NA, height = NA, dpi = 600, write = NULL, append = TRUE,
check = TRUE, output = TRUE, ...)
x |
a numeric vector of data values. |
... |
further arguments to be passed to or from methods. |
y |
a numeric vector of data values. |
mu |
a numeric value indicating the population mean under the
null hypothesis. Note that the argument |
paired |
logical: if |
alternative |
a character string specifying the alternative hypothesis,
must be one of |
hypo |
logical: if |
descript |
logical: if |
effsize |
logical: if |
weighted |
logical: if |
cor |
logical: if |
ref |
character string |
correct |
logical: if |
conf.level |
a numeric value between 0 and 1 indicating the confidence level of the interval. |
digits |
an integer value indicating the number of decimal places to be used for displaying descriptive statistics and confidence interval. |
p.digits |
an integer value indicating the number of decimal places to be used for displaying the p-value. |
as.na |
a numeric vector indicating user-defined missing values,
i.e. these values are converted to |
plot |
logical: if |
bar |
logical: if |
point |
logical: if |
ci |
logical: if |
jitter |
logical: if |
line |
logical: if |
adjust |
logical: if |
filename |
a character string indicating the |
width |
a numeric value indicating the |
height |
a numeric value indicating the |
dpi |
a numeric value indicating the |
write |
a character string naming a text file with file extension
|
append |
logical: if |
check |
logical: if |
output |
logical: if |
formula |
in case of two sample t-test (i.e., |
data |
a matrix or data frame containing the variables in the
formula |
Returns an object of class misty.object, which is a list with following
entries:
call |
function call |
type |
type of analysis |
sample |
type of sample, i.e., one-, two-, or paired sample |
formula |
formula |
data |
data frame with the outcome and grouping variable |
args |
specification of function arguments |
plot |
ggplot2 object for plotting the results |
result |
result table |
Takuya Yanagida takuya.yanagida@univie.ac.at
Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). Statistics in psychology - Using R and SPSS. John Wiley & Sons.
aov.b, aov.w, test.welch,
test.z, test.levene, cohens.d,
ci.mean.diff, ci.mean
#————————————————————————————————————————————————————————————————————————————
# One-Sample Design
# Example 1a: Two-sided one-sample t-test, population mean = 20
test.t(mtcars$mpg, mu = 20)
# Example 1b: One-sided one-sample t-test, population mean = 20, print Cohen's d
test.t(mtcars$mpg, mu = 20, alternative = "greater", effsize = TRUE)
#————————————————————————————————————————————————————————————————————————————
# Two-Sample Design
# Example 2a: Two-sided two-sample t-test
test.t(mpg ~ vs, data = mtcars)
# Example 2b: Two-sided two-sample t-test, alternative specification
test.t(c(3, 1, 4, 2, 5, 3, 6, 7), c(5, 2, 4, 3, 1))
# Example 2c: One-sided two-sample t-test, print Cohen's d
test.t(mpg ~ vs, data = mtcars, alternative = "greater", effsize = TRUE)
#————————————————————————————————————————————————————————————————————————————
# Paired-Sample Design
# Example 3a: Two-sided paired-sample t-test
test.t(mtcars$drat, mtcars$wt, paired = TRUE)
# Example 3b: One-sided paired-sample t-test, print Cohen's d
test.t(mtcars$drat, mtcars$wt, paired = TRUE, alternative = "greater", effsize = TRUE)
#————————————————————————————————————————————————————————————————————————————
# Plot
# Example 4a: One-Sample Design
test.t(mtcars$mpg, mu = 20, plot = TRUE)
# Example 4b: Two-Sample Design
test.t(mpg ~ vs, data = mtcars, plot = TRUE)
# Example 4c: Paired-Sample Design
test.t(mtcars$drat, mtcars$wt, paired = TRUE, plot = TRUE)
# Example 4d: Plot results using the plot() function, use additional arguments
# see Details in the help page of the function plot.misty.object
object <- test.t(mpg ~ vs, data = mtcars)
plot(object, jitter = TRUE, jitter.alpha = 0.4, title = "Two-Sample t-Test")
#————————————————————————————————————————————————————————————————————————————
# Create Plot Manually
# Load ggplot2 package
library(ggplot2)
# Example 4a: Two-sample t-test
ci.table <- ci.mean(mtcars, mpg, group = "vs", adjust = TRUE, output = FALSE)$result
ggplot(ci.table, aes(group, m)) +
geom_bar(aes(group, m), stat = "summary", fun = "mean") +
geom_errorbar(aes(group, m, ymin = low, ymax = upp), width = 0.1) +
theme_bw()
# Example 4b: Paired-sample t-test
object <- test.t(mtcars$drat, mtcars$wt, paired = TRUE)
ggplot(data.frame(x = object$data$y - object$data$x), aes(x = 0L, y = x)) +
geom_bar(data = object$result, aes(0, m.diff), stat = "summary", fun = "mean") +
geom_errorbar(data = object$result, aes(0, m.diff, ymin = m.low, ymax = m.upp), width = 0.1) +
geom_hline(yintercept = 0L, linetype = 3, linewidth = 0.8) +
scale_x_continuous(name = "", limits = c(-2, 2)) +
theme_bw() +
theme(axis.text.x = element_blank(), axis.ticks.x = element_blank())
#————————————————————————————————————————————————————————————————————————————
# Write Results and Save Plot
## Not run:
# Example 6a: Write results into a text file
test.t(mpg ~ vs, data = mtcars, write = "t-Test.txt")
# Example 6b: Write results into an Excel file
test.t(mpg ~ vs, data = mtcars, write = "t-Test.xlsx")
# Example 6c: Save plot as PNG fine
test.t(mpg ~ vs, data = mtcars, plot = TRUE, filename = "t-Test.png",
width = 6, height = 5)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.